@@ -117,7 +117,6 @@ about_cb (BonoboUIComponent          *uic,
 	  AccessxStatusApplet        *sapplet,
 	  const gchar                *verbname)
 {
-	static GtkWidget *about = NULL;
 	GdkPixbuf	 *pixbuf;
 	GError		 *error = NULL;
 	gchar		 *file;
@@ -129,16 +128,15 @@ about_cb (BonoboUIComponent          *uic,
 	};
 
 	const gchar *documenters[] = {
+	        "Bill Haneman <bill.haneman@sun.com>",
+                "Sun GNOME Documentation Team <gdocteam@sun.com>",
 		NULL
 	};
 
 	const gchar *translator_credits = _("translator_credits");
 
-	if (about) {
-		gtk_window_set_screen (
-			GTK_WINDOW (about),
-			gtk_widget_get_screen (GTK_WIDGET (sapplet->applet)));
-		gtk_window_present (GTK_WINDOW (about));
+	if (sapplet->about_dialog) {
+		gtk_window_present (GTK_WINDOW (sapplet->about_dialog));
 		return;
 	}
         
@@ -153,25 +151,24 @@ about_cb (BonoboUIComponent          *uic,
 		g_error_free (error);
 	}
 	
-        about = gnome_about_new (
-		_("AccessX Status"), VERSION,
-		_("Copyright (C) 2003 Sun Microsystems"),
-		_("Shows the state of AccessX features such as latched modifiers"),
-		authors,
-		documenters,
-		strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-		pixbuf);
+        sapplet->about_dialog = gnome_about_new (_("AccessX Status"), VERSION,
+						 _("Copyright (C) 2003 Sun Microsystems"),
+						 _("Shows the state of AccessX features such as latched modifiers"),
+						 authors,
+						 documenters,
+						 strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+						 pixbuf);
 		
 	if (pixbuf)
 		gdk_pixbuf_unref (pixbuf);
 			
-	gtk_window_set_wmclass (GTK_WINDOW (about), "accessx status", "AccessX Status");
-	gtk_window_set_screen (GTK_WINDOW (about),
+	gtk_window_set_wmclass (GTK_WINDOW (sapplet->about_dialog), "accessx status", "AccessX Status");
+	gtk_window_set_screen (GTK_WINDOW (sapplet->about_dialog),
 			       gtk_widget_get_screen (GTK_WIDGET (sapplet->applet)));
-	g_signal_connect (about, "destroy",
+	g_signal_connect (sapplet->about_dialog, "destroy",
 			  G_CALLBACK (gtk_widget_destroyed),
-			  &about);
-        gtk_widget_show (about);
+			  &sapplet->about_dialog);
+	gtk_widget_show (sapplet->about_dialog);
 }
 
 static void
@@ -321,11 +318,9 @@ accessx_status_applet_init_modifiers (AccessxStatusApplet *sapplet)
 			modifiers[i].indicator = sapplet->hyper_indicator;
 		else if (modifiers[i].mask == super_mask)
 			modifiers[i].indicator = sapplet->super_indicator;
-#if 0 
 		/* due to some XKB/XFree weirdness, AltGr doesn't give notifications */
 		else if (modifiers[i].mask == alt_gr_mask)
 			modifiers[i].indicator = sapplet->alt_graph_indicator;
-#endif
 	}
 }
 
@@ -418,7 +413,7 @@ static GdkPixbuf *
 accessx_status_applet_slowkeys_image (AccessxStatusApplet *sapplet, 
 				      XkbAccessXNotifyEvent *event)
 {
-	GdkPixbuf *icon_base;
+	GdkPixbuf *icon_base, *ret_pixbuf;
 	gboolean is_idle = TRUE;
 	gchar *stock_id = SLOWKEYS_IDLE_ICON;
 	GtkStyle *style = gtk_widget_get_style (GTK_WIDGET (sapplet->applet));
@@ -453,14 +448,18 @@ accessx_status_applet_slowkeys_image (AccessxStatusApplet *sapplet,
 			break;
 		}
 	}
-	icon_base = gtk_widget_render_icon (GTK_WIDGET (sapplet->applet),
-					    stock_id,
-					    icon_size_spec,
-					    NULL);
+	ret_pixbuf = gtk_widget_render_icon (GTK_WIDGET (sapplet->applet),
+					     stock_id,
+					     icon_size_spec,
+					     NULL);
 	if (!is_idle) {
-		GdkPixbuf *glyph_pixbuf;
+		GdkPixbuf *glyph_pixbuf, *tmp_pixbuf;
 		GdkColor  fg;
 		gchar * glyphstring = N_("a");
+		tmp_pixbuf = ret_pixbuf;
+		ret_pixbuf = gdk_pixbuf_copy (tmp_pixbuf);
+		g_object_unref (tmp_pixbuf);
+
 		if (event && GTK_WIDGET (sapplet->applet)->window) {
 			KeySym keysym = XKeycodeToKeysym (
 				GDK_WINDOW_XDISPLAY (GTK_WIDGET (sapplet->applet)->window),
@@ -474,17 +473,17 @@ accessx_status_applet_slowkeys_image (AccessxStatusApplet *sapplet,
 		fg = style->fg[GTK_WIDGET_STATE (sapplet->applet)];
 		glyph_pixbuf = accessx_status_applet_get_glyph_pixbuf (sapplet, 
 								       GTK_WIDGET (sapplet->applet),
-								       icon_base, 
+								       ret_pixbuf, 
 								       &fg,
 								       &bg,
 								       glyphstring);
-		gdk_pixbuf_composite (glyph_pixbuf, icon_base, 0, 0, 
+		gdk_pixbuf_composite (glyph_pixbuf, ret_pixbuf, 0, 0, 
 				      gdk_pixbuf_get_width (glyph_pixbuf),
 				      gdk_pixbuf_get_height (glyph_pixbuf), 
 				      0., 0., 1.0, 1.0, GDK_INTERP_NEAREST, 255);
-		gdk_pixbuf_unref (glyph_pixbuf);
+		g_object_unref (glyph_pixbuf);
 	}
-	return icon_base;
+	return ret_pixbuf;
 }
 
 static GdkPixbuf *
@@ -492,7 +491,8 @@ accessx_status_applet_bouncekeys_image (AccessxStatusApplet *sapplet, XkbAccessX
 {
 	GtkStyle  *style;
 	GdkColor   fg, bg;
-	GdkPixbuf *icon_base;
+	GdkPixbuf *icon_base, *tmp_pixbuf;
+	/* Note to translators: the first letter of the alphabet, not the indefinite article */
 	gchar     *glyphstring = N_("a");
 	gchar *stock_id = ACCESSX_BASE_ICON;
 
@@ -515,22 +515,29 @@ accessx_status_applet_bouncekeys_image (AccessxStatusApplet *sapplet, XkbAccessX
 			break;
 		}
 	}
-	icon_base = gtk_widget_render_icon (GTK_WIDGET (sapplet->applet),
-					    stock_id,
-					    icon_size_spec,
-					    NULL);
-	if (icon_base) {
+	tmp_pixbuf = gtk_widget_render_icon (GTK_WIDGET (sapplet->applet),
+					     stock_id,
+					     icon_size_spec,
+					     NULL);
+	if (tmp_pixbuf) {
 		GdkPixbuf   *glyph_pixbuf;
+		icon_base = gdk_pixbuf_copy (tmp_pixbuf);
+		g_object_unref (tmp_pixbuf);
 		glyph_pixbuf = accessx_status_applet_get_glyph_pixbuf (sapplet, 
 								       GTK_WIDGET (sapplet->applet),
 								       icon_base, 
 								       &fg,
 								       &bg,
 								       glyphstring);
-		gdk_pixbuf_composite (glyph_pixbuf, icon_base, 0, 0, 
-				      gdk_pixbuf_get_width (glyph_pixbuf),
-				      gdk_pixbuf_get_height (glyph_pixbuf), 
-				      0., 0., 1.0, 1.0, GDK_INTERP_NEAREST, 255);
+		gdk_pixbuf_composite (glyph_pixbuf, icon_base, 2, 2, 
+				      gdk_pixbuf_get_width (glyph_pixbuf) - 2,
+				      gdk_pixbuf_get_height (glyph_pixbuf) - 2, 
+				      -2., -2., 1.0, 1.0, GDK_INTERP_NEAREST, 96);
+		gdk_pixbuf_composite (glyph_pixbuf, icon_base, 1, 1, 
+				      gdk_pixbuf_get_width (glyph_pixbuf) - 1,
+				      gdk_pixbuf_get_height (glyph_pixbuf) - 1, 
+				      1., 1., 1.0, 1.0, GDK_INTERP_NEAREST, 255);
+
 		gdk_pixbuf_unref (glyph_pixbuf);
 	}
 	return icon_base;
@@ -539,12 +546,14 @@ accessx_status_applet_bouncekeys_image (AccessxStatusApplet *sapplet, XkbAccessX
 static GdkPixbuf *
 accessx_status_applet_mousekeys_image (AccessxStatusApplet *sapplet, XkbStateNotifyEvent *event)
 {
-	GdkPixbuf  *mouse_pixbuf = NULL, *button_pixbuf, *dot_pixbuf;
+	GdkPixbuf  *mouse_pixbuf = NULL, *button_pixbuf, *dot_pixbuf, *tmp_pixbuf;
 	gchar *which_dot = MOUSEKEYS_DOT_LEFT;
-	mouse_pixbuf = gtk_widget_render_icon (GTK_WIDGET (sapplet->applet),
+	tmp_pixbuf = gtk_widget_render_icon (GTK_WIDGET (sapplet->applet),
 					       MOUSEKEYS_BASE_ICON,
 					       icon_size_spec, 
 					       NULL);
+	mouse_pixbuf = gdk_pixbuf_copy (tmp_pixbuf);
+	g_object_unref (tmp_pixbuf);
 	/* composite in the buttons */
 	if (mouse_pixbuf && event && event->ptr_buttons) {
 		gint i;
@@ -554,7 +563,6 @@ accessx_status_applet_mousekeys_image (AccessxStatusApplet *sapplet, XkbStateNot
 									button_icons[i].stock_id,
 									icon_size_spec,
 									NULL);
-				/* Q: does rendering the icon increment a ref count ? */
 				gdk_pixbuf_composite (button_pixbuf, mouse_pixbuf, 0, 0, 
 						      gdk_pixbuf_get_width (button_pixbuf),
 						      gdk_pixbuf_get_height (button_pixbuf), 
@@ -580,7 +588,7 @@ accessx_status_applet_mousekeys_image (AccessxStatusApplet *sapplet, XkbStateNot
 					     which_dot,
 					     icon_size_spec,
 					     NULL);
-	/* Q: does rendering the icon increment a ref count ? */
+
 	gdk_pixbuf_composite (dot_pixbuf, mouse_pixbuf, 0, 0, 
 			      gdk_pixbuf_get_width (dot_pixbuf),
 			      gdk_pixbuf_get_height (dot_pixbuf), 
@@ -792,6 +800,7 @@ accessx_status_applet_altgraph_icon_set (AccessxStatusApplet *sapplet, GtkWidget
 	gint         i;
 	GtkStateType states[3] = {GTK_STATE_NORMAL, GTK_STATE_INSENSITIVE, GTK_STATE_SELECTED};
 	GtkStyle    *style = gtk_widget_get_style (widget);
+	GdkPixbuf   *icon_base;
 
 	for (i = 0; i < 3; ++i) {
 		int alpha;
@@ -823,8 +832,10 @@ accessx_status_applet_altgraph_icon_set (AccessxStatusApplet *sapplet, GtkWidget
 			gtk_widget_set_sensitive (widget, FALSE);
 			break;
 		}
-		pixbuf = gtk_widget_render_icon (widget,
+		icon_base = gtk_widget_render_icon (widget,
 			ACCESSX_BASE_ICON, icon_size_spec, NULL);
+		pixbuf = gdk_pixbuf_copy (icon_base);
+		g_object_unref (icon_base);
 		glyph_pixbuf = accessx_status_applet_get_glyph_pixbuf (sapplet, 
 								       widget,
 								       pixbuf, 
@@ -949,7 +960,7 @@ accessx_status_applet_layout_box (AccessxStatusApplet *sapplet, GtkWidget *box,
 
 	atko = gtk_widget_get_accessible (sapplet->box);
 	atk_object_set_name (atko, "AccessX Status");
-	atk_object_set_description (atko, "Shows kkeyboard status when accessibility features are used.");
+	atk_object_set_description (atko, "Shows keyboard status when accessibility features are used.");
 
 	gtk_widget_show (sapplet->box);
 	gtk_widget_show (GTK_WIDGET (sapplet->applet));
@@ -1047,7 +1058,7 @@ create_applet (PanelApplet *applet)
 	accessx_status_applet_layout_box (sapplet, box, stickyfoo);
 	atko = gtk_widget_get_accessible (GTK_WIDGET (sapplet->applet));
 	atk_object_set_name (atko, "AccessX Status");
-	atk_object_set_description (atko, "Shows kkeyboard status when accessibility features are used.");
+	atk_object_set_description (atko, "Shows keyboard status when accessibility features are used.");
 	return sapplet;
 }
 
@@ -1063,6 +1074,8 @@ accessx_status_applet_destroy (GtkWidget *widget, gpointer user_data)
 		XkbFreeKeyboard (sapplet->xkb, 0, True);
 	if (sapplet->xkb_display) 
 		XCloseDisplay (sapplet->xkb_display);
+	if (sapplet->about_dialog)
+		gtk_widget_destroy (sapplet->about_dialog);
 	if (sapplet->tooltips)
 		g_object_unref (sapplet->tooltips);
 }
@@ -1173,6 +1186,8 @@ accessx_status_applet_fill (PanelApplet *applet)
 					      NULL);
 	}
 
+	sapplet->about_dialog = NULL;
+
 	sapplet->tooltips = gtk_tooltips_new ();
 	g_object_ref (sapplet->tooltips);
 	gtk_object_sink (GTK_OBJECT (sapplet->tooltips));
