@@ -17,7 +17,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0R (Compaq Armada M700)
  *
-$Id: battstat.h,v 1.19 2003/12/17 16:33:03 kevinv Exp $
+$Id: battstat.h,v 1.20 2004/01/30 20:46:34 dsmit Exp $
  */
 
 #define DEBUG 0
@@ -72,7 +72,7 @@ typedef struct _ProgressData {
   GtkWidget *pixmapwidy;
   GtkWidget *ac_event_box;
   GtkWidget *progress_event_box;
-  GtkWidget *about_box;
+  GtkWidget *about_dialog;
   GtkDialog *prop_win;
   GtkWidget *hbox;
   GtkWidget *hbox1;
