@@ -18,7 +18,7 @@
  *
  * May, 2000. Implemented on FreeBSD 4.0-RELEASE (Compaq Armada M700)
  *
- $Id: battstat_applet.c,v 1.59 2004/01/11 10:00:17 bviswa Exp $
+ $Id: battstat_applet.c,v 1.63 2004/02/01 17:03:09 kevinv Exp $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -712,6 +712,9 @@ destroy_applet (GtkWidget *widget, gpointer data)
    
    if (DEBUG) g_print("destroy_applet()\n");
 
+   if (pdata->about_dialog)
+	gtk_widget_destroy (pdata->about_dialog);
+
    if (pdata->prop_win)
 	gtk_widget_destroy (GTK_WIDGET (pdata->prop_win));
 
@@ -859,24 +862,11 @@ suspend_cb (BonoboUIComponent *uic,
    return;
 }
 
-void
-destroy_about (GtkWidget *w, gpointer data)
-{
-   ProgressData *battstat = data;
-   
-   if (DEBUG) g_print("destroy_about()\n");
-   
-   battstat->about_box = NULL;
-   
-   return;
-}
-
 void
 about_cb (BonoboUIComponent *uic,
 	  ProgressData      *battstat,
 	  const char        *verb)
 {
-   GtkWidget   *about_box;
    GdkPixbuf   *pixbuf;
    GError      *error = NULL;
    gchar       *file;
@@ -891,10 +881,20 @@ about_cb (BonoboUIComponent *uic,
    };
 
    const gchar *documenters[] = {
+        "Jorgen Pehrson <jp@spektr.eu.org>",
+        "Trevor Curtis <tcurtis@somaradio.ca>",
 	NULL
    };
 
    const gchar *translator_credits = _("translator_credits");
+
+   if (battstat->about_dialog) {
+	gtk_window_set_screen (GTK_WINDOW (battstat->about_dialog),
+			       gtk_widget_get_screen (GTK_WIDGET (battstat->applet)));
+	   
+	gtk_window_present (GTK_WINDOW (battstat->about_dialog));
+	return;
+   }
    
    file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "battstat.png", FALSE, NULL);
    pixbuf = gdk_pixbuf_new_from_file (file, &error);
@@ -905,7 +905,7 @@ about_cb (BonoboUIComponent *uic,
 	g_error_free (error);
    }
    
-   about_box = gnome_about_new (
+   battstat->about_dialog = gnome_about_new (
 				/* The long name of the applet in the About dialog.*/
 				_("Battery Charge Monitor"), 
 				VERSION,
@@ -919,10 +919,15 @@ about_cb (BonoboUIComponent *uic,
    if (pixbuf)
 	g_object_unref (pixbuf);
 
-   gtk_window_set_wmclass (GTK_WINDOW (about_box), "battery charge monitor", "Batter Charge Monitor");
-   gtk_window_set_screen (GTK_WINDOW (about_box),
+   gtk_window_set_wmclass (GTK_WINDOW (battstat->about_dialog), "battery charge monitor", "Batter Charge Monitor");
+   gtk_window_set_screen (GTK_WINDOW (battstat->about_dialog),
 			  gtk_widget_get_screen (battstat->applet));
-   gtk_widget_show (about_box);
+
+   g_signal_connect (battstat->about_dialog, "destroy",
+		     G_CALLBACK (gtk_widget_destroyed),
+		     &battstat->about_dialog);
+
+   gtk_widget_show (battstat->about_dialog);
 }
 
 void
@@ -1564,7 +1569,8 @@ battstat_applet_fill (PanelApplet *applet)
   battstat->orienttype = panel_applet_get_orient (applet);
   battstat->panelsize = panel_applet_get_size (applet);
   battstat->horizont = TRUE;
-  
+  battstat->about_dialog = NULL;
+
   glade_init ();
   
   load_preferences(battstat);
