@@ -311,32 +311,6 @@ menuitem_activated (GtkMenuItem *menuitem, charpick_data *curr_data)
 		panel_applet_gconf_set_string (applet, "current_list", curr_data->charlist, NULL);
 }
 
-static void
-add_palette (GtkMenuItem *menuitem, charpick_data *curr_data)
-{
-	PanelApplet *applet = PANEL_APPLET (curr_data->applet);
-	GList *list = curr_data->chartable;
-	gchar *new;
-	
-	new = run_edit_dialog (NULL, _("Add Palette"));
-	if (!new)
-		return;
-		
-	list = g_list_append (list, new);
-	if (curr_data->chartable == NULL) {
-		curr_data->chartable = list;
-		curr_data->charlist = curr_data->chartable->data;
-		build_table (curr_data);
-		if (key_writable (PANEL_APPLET (curr_data->applet), "current_list"))
-			panel_applet_gconf_set_string (PANEL_APPLET (curr_data->applet),
-						      "current_list", 
-					  	       curr_data->charlist, NULL);
-	}
-	
-	save_chartable (curr_data);
-  	populate_menu (curr_data);
-}
-
 void
 populate_menu (charpick_data *curr_data)
 {
@@ -364,19 +338,6 @@ populate_menu (charpick_data *curr_data)
 			gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (menuitem), TRUE);
 		list = g_list_next (list);
 	}
-	
-	menuitem = gtk_separator_menu_item_new ();
-	gtk_widget_show (menuitem);
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	
-	menuitem = gtk_menu_item_new_with_label (_("Add a palette..."));
-	gtk_widget_show (menuitem);
-	g_signal_connect (G_OBJECT (menuitem), "activate",
-				   G_CALLBACK (add_palette), curr_data);
-	gtk_menu_shell_append (GTK_MENU_SHELL (menu), menuitem);
-	if ( ! key_writable (PANEL_APPLET (curr_data->applet), "chartable"))
-		gtk_widget_set_sensitive (menuitem, FALSE);
-	
 }
 
 static void
@@ -571,7 +532,6 @@ about (BonoboUIComponent *uic,
        charpick_data     *curr_data,
        const char        *verb)
 {
-  static GtkWidget *about_box = NULL;
   GdkPixbuf   	   *pixbuf;
   GError      	   *error     = NULL;
   gchar            *file;
@@ -585,49 +545,53 @@ about (BonoboUIComponent *uic,
   };
 
   const gchar *documenters[] = {
+          "Dan Mueth <d-mueth@uchicago.edu>",
+          "Sun GNOME Documentation Team <gdocteam@sun.com>",
 	  NULL
   };
 
   const gchar *translator_credits = _("translator_credits");
 
-  if (about_box) {
-	gtk_window_set_screen (GTK_WINDOW (about_box),
-			       gtk_widget_get_screen (curr_data->applet));
-	gtk_window_present (GTK_WINDOW (about_box));
+  if (curr_data->about_dialog) {
+	gtk_window_present (GTK_WINDOW (curr_data->about_dialog));
 	return;
   }
   
-  file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "charpick.png", FALSE, NULL);
+  file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP,
+				    "charpick.png", FALSE, NULL);
   pixbuf = gdk_pixbuf_new_from_file (file, &error);
   g_free (file);
    
   if (error) {
-  	  g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
-	  g_error_free (error);
+	g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+	g_error_free (error);
   }
   
-  about_box = gnome_about_new (_("Character Palette"),
-			       VERSION,
-			       _("Copyright (C) 1998"),
-			       _("Gnome Panel applet for selecting strange "
-			         "characters that are not on my keyboard. "
-				 "Released under GNU General Public Licence."),
-			       authors,
-			       documenters,
-			       strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
-			       pixbuf);
+  curr_data->about_dialog = gnome_about_new (_("Character Palette"),
+					     VERSION,
+					     _("Copyright (C) 1998"),
+					     _("Gnome Panel applet for selecting strange "
+					     "characters that are not on my keyboard. "
+					     "Released under GNU General Public Licence."),
+					     authors,
+					     documenters,
+					     strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+					     pixbuf);
   
   if (pixbuf) 
   	gdk_pixbuf_unref (pixbuf);
-   
-  gtk_window_set_screen (GTK_WINDOW (about_box),
-			 gtk_widget_get_screen (curr_data->applet));
-  gtk_window_set_wmclass (GTK_WINDOW (about_box), "character palette", "Character Palette");
-  gnome_window_icon_set_from_file (GTK_WINDOW (about_box), GNOME_ICONDIR"/charpick.png");
 
-  gtk_signal_connect(GTK_OBJECT(about_box), "destroy",
-		     GTK_SIGNAL_FUNC(gtk_widget_destroyed), &about_box);
-  gtk_widget_show(about_box);
+  gtk_window_set_screen (GTK_WINDOW (curr_data->about_dialog),
+			 gtk_widget_get_screen (curr_data->applet));
+  gtk_window_set_wmclass (GTK_WINDOW (curr_data->about_dialog),
+			  "character palette", "Character Palette");
+  gnome_window_icon_set_from_file (GTK_WINDOW (curr_data->about_dialog),
+				   GNOME_ICONDIR"/charpick.png");
+
+  gtk_signal_connect(GTK_OBJECT(curr_data->about_dialog), "destroy",
+		     GTK_SIGNAL_FUNC(gtk_widget_destroyed),
+		     &curr_data->about_dialog);
+  gtk_widget_show(curr_data->about_dialog);
   return;
 }
 
@@ -659,6 +623,8 @@ applet_destroy (GtkWidget *widget, gpointer data)
 
   g_return_if_fail (curr_data);
    
+  if (curr_data->about_dialog)
+    gtk_widget_destroy (curr_data->about_dialog);   
   if (curr_data->propwindow)
     gtk_widget_destroy (curr_data->propwindow);
 
@@ -772,7 +738,9 @@ charpicker_applet_fill (PanelApplet *applet)
   curr_data = g_new0 (charpick_data, 1);
   curr_data->last_index = NO_LAST_INDEX;
   curr_data->applet = GTK_WIDGET (applet);
-  
+  curr_data->about_dialog = NULL;
+  curr_data->add_edit_dialog = NULL;
+ 
   get_chartable (curr_data);
   
   string  = panel_applet_gconf_get_string (applet, "current_list", NULL);
