@@ -1,4 +1,4 @@
-/* $Id: weather.c,v 1.68 2004/01/09 15:30:10 kevinv Exp $ */
+/* $Id: weather.c,v 1.70 2004/02/01 17:19:43 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -265,7 +265,8 @@ static inline void requests_done_check (WeatherInfo *info)
     g_return_if_fail(info->requests_pending);
 
     if (!info->metar_handle && !info->iwin_handle && 
-        !info->wx_handle && !info->met_handle) {
+        !info->wx_handle && !info->met_handle &&
+	!info->bom_handle) {
         info->requests_pending = FALSE;
         update_finish(info);
     }
@@ -286,6 +287,8 @@ close_cb (GnomeVFSAsyncHandle *handle, GnomeVFSResult result, gpointer data)
 		info->wx_handle = NULL;
 	if (handle == info->met_handle)
 		info->met_handle = NULL;
+	if (handle == info->bom_handle)
+	        info->bom_handle = NULL;
  	
 	requests_done_check(info);
 		
@@ -453,7 +456,7 @@ static gboolean metar_tok_wind (gchar *tokp, WeatherInfo *info)
         gust = atoi(sgust);
     }
 
-    if ((349 <= dir) && (dir <= 11))
+    if ((349 <= dir) || (dir <= 11))
         info->wind = WIND_N;
     else if ((12 <= dir) && (dir <= 33))
         info->wind = WIND_NNE;
@@ -1396,6 +1399,108 @@ static void metoffice_start_open (WeatherInfo *info)
     return;
 }	
 
+static gchar *bom_parse (gchar *meto)
+{ 
+    gchar *p, *rp;
+    
+    p = strstr(meto, "<pre>");
+    p += 5; /* skip the <pre> */
+    rp = strstr(p, "</pre>");
+
+    return g_strndup(p, rp-p);
+}
+
+static void bom_finish_read(GnomeVFSAsyncHandle *handle, GnomeVFSResult result, 
+			    gpointer buffer, GnomeVFSFileSize requested, 
+			    GnomeVFSFileSize body_len, gpointer data)
+{
+    WeatherInfo *info = (WeatherInfo *)data;
+    WeatherLocation *loc;
+    gchar *body, *forecast, *temp;
+
+    info->forecast = NULL;
+    loc = info->location;
+    body = (gchar *)buffer;
+    body[body_len] = '\0';
+	
+    if (info->bom_buffer == NULL)
+        info->bom_buffer = g_strdup(body);
+    else
+    {
+        temp = g_strdup(info->bom_buffer);
+	g_free(info->bom_buffer);
+	info->bom_buffer = g_strdup_printf("%s%s", temp, body);
+	g_free(temp);
+    }
+	
+    if (result == GNOME_VFS_ERROR_EOF)
+    {
+	forecast = bom_parse(info->bom_buffer);
+        info->forecast = forecast;
+    }
+    else if (result != GNOME_VFS_OK) {
+	info->bom_handle = NULL;
+	requests_done_check (info);
+        g_warning("Failed to get BOM data.\n");
+    } else {
+	gnome_vfs_async_read(handle, body, DATA_SIZE - 1, bom_finish_read, info);
+
+	return;
+    }
+    
+    request_done(info->bom_handle, info);
+    g_free (buffer);
+    return;
+}
+
+static void bom_finish_open (GnomeVFSAsyncHandle *handle, GnomeVFSResult result, gpointer data)
+{
+    WeatherInfo *info = (WeatherInfo *)data;
+    WeatherLocation *loc;
+    gchar *body;
+    gint body_len;
+    gchar *forecast;
+
+    g_return_if_fail(handle == info->bom_handle);
+
+    g_return_if_fail(info != NULL);
+
+    body = g_malloc0(DATA_SIZE);
+
+    info->bom_buffer = NULL;
+    if (info->forecast)
+    	g_free (info->forecast);	
+    info->forecast = NULL;
+    loc = info->location;
+    g_return_if_fail(loc != NULL);
+
+    if (result != GNOME_VFS_OK) {
+        g_warning("Failed to get BOM forecast data.\n");
+        info->bom_handle = NULL;
+        requests_done_check (info);
+        g_free (body);
+    } else {
+    	gnome_vfs_async_read(handle, body, DATA_SIZE - 1, bom_finish_read, info);
+    }
+    return;
+}
+
+static void bom_start_open (WeatherInfo *info)
+{
+    gchar *url;
+    WeatherLocation *loc;
+    loc = info->location;
+  
+    url = g_strdup_printf("http://www.bom.gov.au/cgi-bin/wrap_fwo.pl?%s.txt",
+			  loc->zone+1);
+
+    gnome_vfs_async_open(&info->bom_handle, url, GNOME_VFS_OPEN_READ, 
+    			 0, bom_finish_open, info);
+    g_free(url);
+
+    return;
+}	
+
 /* Get forecast into newly alloc'ed string */
 static void iwin_start_open (WeatherInfo *info)
 {
@@ -1414,6 +1519,11 @@ static void iwin_start_open (WeatherInfo *info)
     	metoffice_start_open (info);
     	return;
     }
+    if (loc->zone[0] == '@')    /* Australian BOM forecasts */
+    {
+    	bom_start_open (info);
+    	return;
+    }
     
 #if 0
     if (weather_forecast == FORECAST_ZONE)
@@ -1566,6 +1676,7 @@ gboolean _weather_info_fill (GWeatherApplet *applet, WeatherInfo *info, WeatherL
     	info->iwin_handle = NULL;
     	info->wx_handle = NULL;
     	info->met_handle = NULL;
+	info->bom_handle = NULL;
     	info->requests_pending = FALSE;
     	info->metar_buffer = NULL;
     	info->iwin_buffer = NULL; 
@@ -1613,6 +1724,7 @@ gboolean _weather_info_fill (GWeatherApplet *applet, WeatherInfo *info, WeatherL
     info->iwin_handle = NULL;
     info->wx_handle = NULL;
     info->met_handle = NULL;
+    info->bom_handle = NULL;
     info->requests_pending = TRUE;
     info->applet = applet;
 
