@@ -312,7 +312,7 @@ mc_show_history (GtkWidget *widget,
      /* add history entries to list */
      if (j == 0) {
           gtk_list_store_append (store, &iter);
-          gtk_list_store_set (store, &iter,0, "no items in history", -1);
+          gtk_list_store_set (store, &iter,0, _("No items in history"), -1);
      }
      else {	
           for(i = 0; i < MC_HISTORY_LIST_LENGTH; i++)
@@ -406,13 +406,14 @@ file_browser_response_signal(GtkWidget *widget, gint response, gpointer mc_data)
     if (response == GTK_RESPONSE_OK) {
         /* get selected file name */
         filename = gtk_file_chooser_get_filename(GTK_FILE_CHOOSER(mc->file_select));
-        strcpy(browsed_filename, (char *) filename);
-	g_free(filename);
+        if (filename != NULL) {
+            strcpy(browsed_filename, (char *) filename);
+            g_free(filename);
+            /* printf("Filename: %s\n", (char *) browsed_filename); */
 
-        /* printf("Filename: %s\n", (char *)  browsed_filename); */
-
-        /* execute command */
-        mc_exec_command(mc, browsed_filename);
+            /* execute command */
+            mc_exec_command(mc, browsed_filename);
+       }
     }
 
     /* destroy file select dialog */
