@@ -211,11 +211,12 @@ add_page(GtkWidget *notebook, gchar *label)
 
 /* save the selected color to gconf and apply it on the applet */
 void
-color_picker_set_cb(GnomeColorPicker *color_picker, guint arg1, guint arg2, guint arg3, guint arg4, gpointer data)
+color_picker_set_cb(GtkColorButton *color_picker, gpointer data)
 {
 	gchar color_string[8];
 	const gchar *gconf_path;
-	guint8 red, green, blue, alpha, prop_type;
+	guint8 prop_type;
+	GdkColor color;
 	MultiloadApplet *ma;
 
 	gconf_path = data;
@@ -236,9 +237,10 @@ color_picker_set_cb(GnomeColorPicker *color_picker, guint arg1, guint arg2, guin
 	else
 		g_assert_not_reached();
 		
-	gnome_color_picker_get_i8(color_picker, &red, &green, &blue, &alpha);
+	gtk_color_button_get_color(color_picker, &color);
 	
-	snprintf(color_string, 8, "#%02X%02X%02X", red, green, blue);
+	snprintf(color_string, 8, "#%02X%02X%02X", 
+		 color.red / 256, color.green / 256, color.blue / 256);
 	panel_applet_gconf_set_string(PANEL_APPLET(ma->applet), gconf_path, color_string, NULL);
 	
 	gdk_color_parse(color_string, 
@@ -256,21 +258,24 @@ add_color_selector(GtkWidget *page, gchar *name, gchar *gconf_path, MultiloadApp
 	GtkWidget *vbox;
 	GtkWidget *label;
 	GtkWidget *color_picker;
+	GdkColor color;
 	gchar *color_string;
-	gint red, green, blue;
 	
 	color_string = panel_applet_gconf_get_string(ma->applet, gconf_path, NULL);
 	if (!color_string)
 		color_string = g_strdup ("#000000");
-	red = g_ascii_xdigit_value(color_string[1]) * 16 + g_ascii_xdigit_value(color_string[2]);
-	green = g_ascii_xdigit_value(color_string[3]) * 16 + g_ascii_xdigit_value(color_string[4]);
-	blue = g_ascii_xdigit_value(color_string[5]) * 16 + g_ascii_xdigit_value(color_string[6]);
+	color.red   = (g_ascii_xdigit_value(color_string[1]) * 16 
+                       + g_ascii_xdigit_value(color_string[2])) * 256;
+	color.green = (g_ascii_xdigit_value(color_string[3]) * 16 
+                       + g_ascii_xdigit_value(color_string[4])) * 256;
+	color.blue  = (g_ascii_xdigit_value(color_string[5]) * 16
+                       + g_ascii_xdigit_value(color_string[6])) * 256;
 		
 	vbox = gtk_vbox_new (FALSE, 6);
 	label = gtk_label_new_with_mnemonic(name);
-	color_picker = gnome_color_picker_new();
+	color_picker = gtk_color_button_new();
 	gtk_label_set_mnemonic_widget (GTK_LABEL (label), color_picker);
-		
+	
 	gtk_box_pack_start(GTK_BOX(vbox), color_picker, FALSE, FALSE, 0);
 	gtk_box_pack_start (GTK_BOX (vbox), label, FALSE, FALSE, 0);
 	
@@ -278,7 +283,7 @@ add_color_selector(GtkWidget *page, gchar *name, gchar *gconf_path, MultiloadApp
 	
 	g_object_set_data (G_OBJECT (color_picker), "MultiloadApplet", ma);
 
-	gnome_color_picker_set_i8(GNOME_COLOR_PICKER(color_picker), red, green, blue, 0);	
+	gtk_color_button_set_color(GTK_COLOR_BUTTON(color_picker), &color);
 
 	g_signal_connect(G_OBJECT(color_picker), "color_set", G_CALLBACK(color_picker_set_cb), gconf_path);
 
